| createDefaultAboutConfig | R Documentation |
Create an R list with the about config specification
createDefaultAboutConfig()
User specifies the settings to create a default config for an about module
An R list with the module config settings
Other ModuleConfig:
createDefaultCharacterizationConfig(),
createDefaultCohortDiagnosticsConfig(),
createDefaultCohortGeneratorConfig(),
createDefaultCohortMethodConfig(),
createDefaultDatasourcesConfig(),
createDefaultEstimationConfig(),
createDefaultEvidenceSynthesisConfig(),
createDefaultHomeConfig(),
createDefaultPhevaluatorConfig(),
createDefaultPredictionConfig(),
createDefaultReportConfig(),
createDefaultSccsConfig(),
createModuleConfig()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.