| createDefaultCohortGeneratorConfig | R Documentation |
Create an R list with the cohort generator config specification
createDefaultCohortGeneratorConfig()
User specifies the settings to create a default config for a cohort generator module
An R list with the module config settings
Other ModuleConfig:
createDefaultAboutConfig(),
createDefaultCharacterizationConfig(),
createDefaultCohortDiagnosticsConfig(),
createDefaultCohortMethodConfig(),
createDefaultDatasourcesConfig(),
createDefaultEstimationConfig(),
createDefaultEvidenceSynthesisConfig(),
createDefaultHomeConfig(),
createDefaultPhevaluatorConfig(),
createDefaultPredictionConfig(),
createDefaultReportConfig(),
createDefaultSccsConfig(),
createModuleConfig()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.