| createDefaultCohortMethodConfig | R Documentation |
Create an R list with the cohort method config specification (depreciated)
createDefaultCohortMethodConfig()
User specifies the settings to create a default config for a cohort method module
An R list with the module config settings
Other ModuleConfig:
createDefaultAboutConfig(),
createDefaultCharacterizationConfig(),
createDefaultCohortDiagnosticsConfig(),
createDefaultCohortGeneratorConfig(),
createDefaultDatasourcesConfig(),
createDefaultEstimationConfig(),
createDefaultEvidenceSynthesisConfig(),
createDefaultHomeConfig(),
createDefaultPhevaluatorConfig(),
createDefaultPredictionConfig(),
createDefaultReportConfig(),
createDefaultSccsConfig(),
createModuleConfig()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.