| createDefaultEstimationConfig | R Documentation |
Create an R list with the estimation config specification
createDefaultEstimationConfig()
User specifies the settings to create a default config for an estimation module
An R list with the module config settings
Other ModuleConfig:
createDefaultAboutConfig(),
createDefaultCharacterizationConfig(),
createDefaultCohortDiagnosticsConfig(),
createDefaultCohortGeneratorConfig(),
createDefaultCohortMethodConfig(),
createDefaultDatasourcesConfig(),
createDefaultEvidenceSynthesisConfig(),
createDefaultHomeConfig(),
createDefaultPhevaluatorConfig(),
createDefaultPredictionConfig(),
createDefaultReportConfig(),
createDefaultSccsConfig(),
createModuleConfig()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.