saveConfig: saveConfig

View source: R/saveLoadConfig.R

saveConfigR Documentation

saveConfig

Description

Save the R list with the config specification as a json

Usage

saveConfig(configList, configLocation)

Arguments

configList

An R list with the config settings

configLocation

The location to save the config json file

Details

User saves the R list with the config as a json file

Value

An R list with the config settings

See Also

Other Config: addModuleConfig(), initializeModuleConfig(), loadConfig()


OhdsiShinyAppBuilder documentation built on July 23, 2026, 1:07 a.m.